// CopySession.cpp : implementation file
//

#include "stdafx.h"
#include "rootfly.h"
#include "CopySessionDlg.h"
#include <assert.h>

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CCopySessionDlg dialog


CCopySessionDlg::CCopySessionDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CCopySessionDlg::IDD, pParent),
  m_first_radio(IDC_RADIO_COPY_ALLWINDOWTUBE), 
  m_last_radio(IDC_RADIO_COPY_JUSTONEROOTINCURRENTWINDOWTUBE)
{
  m_copy_what = ALL_ROOTS_IN_THIS_WINDOW_TUBE;
  m_curr = 1;
	//{{AFX_DATA_INIT(CCopySessionDlg)
	m_copy_to = 1;
	m_copy_from = 2;
  m_copy_whichroot = 1;
	//}}AFX_DATA_INIT
}

/**
* Sets the default destination value in the copy session dialog box
* @return unsigned int the user chose within the copy session dialog box for the source session.
*/
unsigned int CCopySessionDlg::GetSource() 
{
  return m_copy_from;
}


/**
* Sets the default destination value in the copy session dialog box
* @return unsigned int the user chose within the copy session dialog box for the destination session.
*/
unsigned int CCopySessionDlg::GetDestination()
{
  return m_copy_to;
}

/**
*/
unsigned int CCopySessionDlg::GetWhichRoot()
{
  return m_copy_whichroot;
}


/**
* Sets the default destination value in the copy session dialog box
* @param source unsigned int which sets the default display source session value in the dialog box
* @return unsigned int the user chose within the copy session dialog box.
*/
bool CCopySessionDlg::SetSource(unsigned int source)
{
  if(source == 0) 
  {
    return false;
  }

  m_copy_from = source;

  return true;

}

/**
* Sets the default destination value in the copy session dialog box
* @param destination unsigned int representing the destination session number, must be >= 1
* @return bool indicating success(true) or failure(false)
*/
bool CCopySessionDlg::SetDestination(unsigned int destination)
{
  if(destination == 0) 
  {
    return false;
  }

  m_copy_to = destination;

  return true;
}

bool CCopySessionDlg::SetWhichRoot(unsigned int whichroot)
{
  if(whichroot == 0) 
  {
    return false;
  }

  m_copy_whichroot = whichroot;

  return true;
}

/**
* Sets the current session number in the copy session dialog box
* @param curr unsigned int representing the current session number, must be >= 1
* @return bool indicating success(true) or failure(false)
*/
bool CCopySessionDlg::SetCurrent(unsigned int curr)
{
  if(curr == 0) 
  {
    return false;
  }

  m_curr = curr;

  return true;
}

void CCopySessionDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CCopySessionDlg)
	DDX_Text(pDX, IDC_EDIT_COPYTO, m_copy_to);
	DDX_Text(pDX, IDC_EDIT_COPYFROM, m_copy_from);
	DDX_Text(pDX, IDC_EDIT_COPYWHICHROOT, m_copy_whichroot);
	//}}AFX_DATA_MAP
}

/**
* Sets the default destination value in the copy session dialog box
* @return bool indicating whether the user checked the copy all roots in the tube checkbox
*/
CCopySessionDlg::CopyWhat CCopySessionDlg::GetCopyWhat() 
{
  return m_copy_what;
}

int CCopySessionDlg::GetCopyWhichRoot()
{
  return (int) m_copy_whichroot;
}


BEGIN_MESSAGE_MAP(CCopySessionDlg, CDialog)
	//{{AFX_MSG_MAP(CCopySessionDlg)
	ON_BN_CLICKED(IDC_RADIO_COPY_ALLWINDOWTUBE, OnRadioCopyAllwindowtube)
	ON_BN_CLICKED(IDC_RADIO_COPY_CURRENTWINDOWTUBE, OnRadioCopyCurrentwindowtube)
	ON_BN_CLICKED(IDC_RADIO_COPY_JUSTONEROOTINCURRENTWINDOWTUBE, OnRadioCopyJustonerootincurrentwindowtube)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

void CCopySessionDlg::EnableDisable()
{
  unsigned int ret = GetCheckedRadioButton(m_first_radio, m_last_radio);
  bool enable = (ret == IDC_RADIO_COPY_JUSTONEROOTINCURRENTWINDOWTUBE);
  CWnd* wnd;
  wnd = GetDlgItem(IDC_EDIT_COPYWHICHROOT);
  if (wnd)  wnd->ShowWindow( enable ? SW_SHOW : SW_HIDE );
// if (wnd)  wnd->EnableWindow( enable );
  wnd = GetDlgItem(IDC_STATIC_COPY_ROOTID);
  if (wnd)  wnd->ShowWindow( enable ? SW_SHOW : SW_HIDE );  
}

/////////////////////////////////////////////////////////////////////////////
// CCopySessionDlg message handlers

BOOL CCopySessionDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();

  unsigned default_radio = IDC_RADIO_COPY_CURRENTWINDOWTUBE;
//  CheckRadioButton(IDC_RADIO_COPY_CURRENTWINDOWTUBE, IDC_RADIO_COPY_ALLWINDOWTUBE, default_radio);	
  CheckRadioButton(m_first_radio, m_last_radio, default_radio);	

  CWnd* wnd = GetDlgItem(IDC_STATIC_COPYSESSION_CURSES);
  if (wnd)  
  {
    CString str;
    str.Format("(Current session is %d.)", m_curr);
    wnd->SetWindowText(str);
  }

  EnableDisable();

  return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void CCopySessionDlg::OnOK() 
{
//  unsigned int ret = GetCheckedRadioButton(IDC_RADIO_COPY_CURRENTWINDOWTUBE, IDC_RADIO_COPY_ALLWINDOWTUBE);
  unsigned int ret = GetCheckedRadioButton(m_first_radio, m_last_radio);
//  m_copy_all_tubes = (ret == IDC_RADIO_COPY_ALLWINDOWTUBE);
	
  switch (ret)
  { 
  case IDC_RADIO_COPY_ALLWINDOWTUBE:  m_copy_what = ALL_ROOTS_IN_ALL_WINDOWS_TUBES;  break;
  case IDC_RADIO_COPY_CURRENTWINDOWTUBE:  m_copy_what = ALL_ROOTS_IN_THIS_WINDOW_TUBE;  break;
  case IDC_RADIO_COPY_JUSTONEROOTINCURRENTWINDOWTUBE:  m_copy_what = JUST_SINGLE_ROOT;  break;
  default:
    assert(0);
    m_copy_what = ALL_ROOTS_IN_THIS_WINDOW_TUBE;
  }

	CDialog::OnOK();
}

void CCopySessionDlg::OnRadioCopyAllwindowtube() 
{
  CheckRadioButton(m_first_radio, m_last_radio, IDC_RADIO_COPY_ALLWINDOWTUBE);	
  EnableDisable();
}

void CCopySessionDlg::OnRadioCopyCurrentwindowtube() 
{
  CheckRadioButton(m_first_radio, m_last_radio, IDC_RADIO_COPY_CURRENTWINDOWTUBE);	
  EnableDisable();
}

void CCopySessionDlg::OnRadioCopyJustonerootincurrentwindowtube() 
{
  CheckRadioButton(m_first_radio, m_last_radio, IDC_RADIO_COPY_JUSTONEROOTINCURRENTWINDOWTUBE);	
  EnableDisable();
}
